Overview
--------

The following sections describe the parts of the Device plugin.

Enrolment
`````````

The device plugin provides enrollment for user devices or browsers connecting to the
peek client service.

If a device is not enrolled in the admin interface, the device won't be able to the
peek UI.

Online Status
`````````````

The device plugin provides the online/offline status of the users devices.

This can be used with integrations to other systems when Peek is used for mobility.
